@@ -1,6 +1,6 @@
 /********************************************
 repl.h
-copyright 2009,2010, Thomas E. Dickey
+copyright 2009-2014,2020, Thomas E. Dickey
 copyright 1991,1993, Michael D. Brennan
 
 This is a source file for mawk, an implementation of
@@ -11,14 +11,7 @@ the GNU General Public License, version 2, 1991.
 ********************************************/
 
 /*
- * $MawkId: repl.h,v 1.7 2010/12/10 17:00:00 tom Exp $
- * @Log: repl.h,v @
- * Revision 1.1.1.1  1993/07/03  18:58:19  mike
- * move source to cvs
- *
- * Revision 5.1  1991/12/05  07:59:32  brennan
- * 1.1 pre-release
- *
+ * $MawkId: repl.h,v 1.9 2020/07/17 23:16:52 tom Exp $
  */
 
 /* repl.h */
@@ -29,14 +22,16 @@ the GNU General Public License, version 2, 1991.
 #include "types.h"
 
 typedef struct re_data {
+    PTR compiled;		/* must be first... */
     int anchored;		/* use to limit recursion in gsub */
-    PTR compiled;
+    int is_empty;		/* check if pattern is empty */
 } RE_DATA;
 
 /*
  * re_compile returns a RE_DATA*, but mawk handles it as a PTR thereafter.
  */
 #define isAnchored(ptr) (((RE_DATA *)(ptr))->anchored)
+#define isEmpty_RE(ptr) (((RE_DATA *)(ptr))->is_empty)
 #define cast_to_re(ptr) (((RE_DATA *)(ptr))->compiled)
 #define refRE_DATA(re)  ((PTR) &(re))
 
